==========
nicfit.py
==========

Common Python utils (App, logging, config, etc.)

Status
------
.. image:: https://img.shields.io/pypi/v/nicfit.py.svg
   :target: https://pypi.python.org/pypi/nicfit.py/
   :alt: Latest Version
.. image:: https://img.shields.io/pypi/status/nicfit.py.svg
   :target: https://pypi.python.org/pypi/nicfit.py/
   :alt: Project Status
.. image:: https://travis-ci.org/nicfit/nicfit.py.svg?branch=master
   :target: https://travis-ci.org/nicfit/nicfit.py
   :alt: Build Status
.. image:: https://img.shields.io/pypi/l/nicfit.py.svg
   :target: https://pypi.python.org/pypi/nicfit.py/
   :alt: License
.. image:: https://img.shields.io/pypi/pyversions/nicfit.py.svg
   :target: https://pypi.python.org/pypi/nicfit.py/
   :alt: Supported Python versions
.. image:: https://coveralls.io/repos/nicfit/nicfit.py/badge.svg
   :target: https://coveralls.io/r/nicfit/nicfit.py
   :alt: Coverage Status

Features
--------

* Free software: MIT license
